@@ -9,7 +9,7 @@ from wagtail.admin.rich_text.converters.html_to_contentstate import InlineStyleE
 from wagtail.admin.menu import MenuItem
 from wagtail.core import hooks
 
-from webspace.cms.bakery import urls as urls_bakery
+from webspace.bakery import urls as urls_bakery
 
 NOTHING_RE = re.compile('a^')
 
@@ -119,36 +119,3 @@ class NoFollowExternalLinkHandler(LinkHandler):
 @hooks.register('register_rich_text_features')
 def register_external_link(features):
     features.register_link_type(NoFollowExternalLinkHandler)
-
-
-#  Bakery
-
-
-class BakeryItem(MenuItem):
-    """
-    Registers wagtail-cache in wagtail admin for superusers.
-    """
-
-    def is_shown(self, request):
-        return request.user.is_superuser
-
-
-@hooks.register('register_admin_urls')
-def register_admin_urls():
-    """
-    Registers wagtail-cache urls in the wagtail admin.
-    """
-    return [
-        path('bakery/', include((urls_bakery, 'bakery'), namespace='bakery')),
-    ]
-
-
-@hooks.register('register_settings_menu_item')
-def register_cache_menu():
-    """
-    Registers wagtail-cache settings panel in the wagtail admin.
-    """
-    return BakeryItem(
-        'Bakery',
-        reverse('bakery:index'),
-        classnames='icon icon-cog')
